@@ -2,6 +2,8 @@ package Blog::Entry;
 use strict;
 use warnings;
 use base qw 'Blog::Class';
+use Blog::User;
+use Blog::Bookmark;
 
 __PACKAGE__->table('entry');
 __PACKAGE__->has_a(
